import type { Emitter } from '../types';
declare type TaskInstruction = string;
declare type TaskEvent = {
    readonly taskName: string;
    readonly instruction: string;
};
declare type ErrorEvent = {
    readonly taskName: string;
    readonly error: Error;
};
/**
 * @property activeTaskInstructions A list of active task instructions as retrieved using `getActiveTaskInstructions`.
 * @property limit A limit derived based on the value of `concurrency` and the number of `activeTaskInstructions` (CONCURRENCY - ACTIVE TASK INSTRUCTIONS = LIMIT).
 */
declare type ScheduleConfiguration = {
    readonly activeTaskInstructions: TaskInstruction[];
    readonly limit: number;
};
/**
 *
 */
declare type Schedule = (configuration: ScheduleConfiguration) => Promise<TaskInstruction[]>;
/**
 * Produces a number (time in milliseconds) representing how long Planton must wait before attempting `schedule` function.
 */
declare type Delay = (attemptNumber: number) => number;
/**
 * @property concurrency Together with `getActiveTaskInstructions`, the `concurrency` setting is used to generate `limit` value that is passed to task scheduler.
 * @property name A unique name of the task. Used to identify task scheduler in errors and for tracking active task instructions (see `getActiveTaskInstructions`).
 */
declare type TaskInput = {
    readonly concurrency?: number;
    readonly delay?: Delay;
    readonly name: string;
    readonly schedule: Schedule;
};
/**
 * @property getActiveTaskInstructions Returns list of tasks that are currently being executed. Used for concurrency control.
 */
declare type PlantonConfiguration = {
    readonly getActiveTaskInstructions: (taskName: string) => TaskInstruction[];
    readonly tasks: TaskInput[];
};
declare type EventMap = {
    error: ErrorEvent;
    task: TaskEvent;
};
declare type Planton = {
    events: Emitter<EventMap>;
    terminate: () => Promise<void>;
};
declare const createPlanton: (configuration: PlantonConfiguration) => Planton;
export { createPlanton, };
